package com.example.gantt;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.jfree.data.gantt.Task;
import org.jfree.data.gantt.TaskSeries;
import org.jfree.data.gantt.TaskSeriesCollection;
import org.jfree.data.time.SimpleTimePeriod;
import org.jfree.data.category.IntervalCategoryDataset;

public class DatasetGantt 
{
	private  SimpleDateFormat   sdf;
	private  String[]  tasks = {"Подготовка предложений", 
			                    "Получение замечаний", 
			                    "Анализ требований", 
			                    "Проектирование", 
			                    "Веха 1-го этапа", 
			                    "Проектная реализация", 
			                    "Замечания по интерфейсу", 
			                    "Доработка интерфейса", 
			                    "Доработанная реализация", 
			                    "Тестирование", 
			                    "Финальное внедрение", 
			                    "Завершение"};
	private  double[][]  states   = {{0.8}, 
			                         {1.0}, 
			                         {1.0, 1.0},
			                         {1.0, 1.0, 0.5},
			                         {0.7}, {0.2}, {0.0}, {0.0},
			                         {0.0}, {0.0}, {0.0}, {0.0}};
	private  String[][] subtasks = {{null},
			                        {null},
			                        {"Задача 3.1", "Задача 3.2"},
			                        {"Задача 4.1", "Задача 4.2", "Задача 4.3"},
			                        {null}, {null}, {null}, {null}, 
			                        {null}, {null}, {null}, {null}};
	private  String[][] subdates = {{null},
			                        {null},
			                        {"2016-04-12", "2016-04-27", 
			                         "2016-04-30", "2016-05-05"},
			                        {"2016-05-06", "2016-05-13", 
			                         "2016-05-15", "2016-05-21",
                                     "2016-05-23", "2016-05-30"},
			                        {null}, {null}, {null}, {null}, 
			                        {null}, {null}, {null}, {null}};
	private  String[][] dates_schedule  = {{"2016-04-01", "2016-04-05"}, 
			                               {"2016-04-09", "2016-04-11"},
			                               {"2016-04-12", "2016-05-05"},
			                               {"2016-05-06", "2016-05-30"},
			                               {"2016-06-02", "2016-06-03"},
			                               {"2016-06-03", "2016-07-31"},
			                               {"2016-08-01", "2016-08-08"},
			                               {"2016-08-10", "2016-08-11"},
			                               {"2016-08-12", "2016-08-14"},
			                               {"2016-08-16", "2016-10-31"},
			                               {"2016-11-01", "2016-11-15"},
			                               {"2016-11-20", "2016-12-23"}};
	private  String[][] dates_actual    = {{"2016-04-01", "2016-04-05"}, 
                                           {"2016-04-09", "2016-04-10"},
                                           {"2016-04-11", "2016-05-06"},
                                           {"2016-05-08", "2016-05-28"},
                                           {"2016-06-01", "2016-06-02"},
                                           {"2016-06-04", "2016-07-27"},
                                           {"2016-07-29", "2016-08-05"},
                                           {"2016-08-07", "2016-08-09"},
                                           {"2016-08-10", "2016-08-15"},
                                           {"2016-08-16", "2016-11-05"},
                                           {"2016-11-07", "2016-11-25"},
                                           {"2016-11-28", "2016-12-19"}};

	public DatasetGantt(){}
	
   /**
     * Метод конвертации текстовой даты в объект Date
     *  
     * @param sdate текстовая дата
     * @return Date объект даты
     */
    private Date date(final String sdate)
    {
    	if (sdf == null)
    		sdf = new SimpleDateFormat("yyyyy-MM-dd");

    	Date date = null;
		try {
			date = sdf.parse(sdate);
		} catch (ParseException e) {
			e.printStackTrace();
		}
        return date;
    }
   /**
     * Создание Dataset плановых и актуальных задач для построения диаграммы Гантта
     * @return Dataset
     */
    public IntervalCategoryDataset createDataset1()
    {
        final TaskSeries s1 = new TaskSeries("Планирование");
        for (int i = 0; i < tasks.length; i++) {
        	s1.add(new Task(tasks[i], new SimpleTimePeriod(date(dates_schedule[i][0]), 
        			                                       date(dates_schedule[i][1]))));
        };

        final TaskSeries s2 = new TaskSeries("Выполнение");
        for (int i = 0; i < (tasks.length - 6); i++) {
        	s2.add(new Task(tasks[i], new SimpleTimePeriod(date(dates_actual[i][0]), 
                                                           date(dates_actual[i][1]))));
        };

        final TaskSeriesCollection collection = new TaskSeriesCollection();
        collection.add(s1);
        collection.add(s2);

        return collection;
    }

    /**
     * Создание Dataset плановых и актуальных задач для построения диаграммы Гантта
     * @return Dataset
     */
    public IntervalCategoryDataset createDataset2()
    {
        final TaskSeries series = new TaskSeries("Состояние задач");
        for (int i = 0; i < tasks.length; i++) {
        	Task task = new Task(tasks[i], 
        			             new SimpleTimePeriod(date(dates_schedule[i][0]), 
                                                      date(dates_schedule[i][1])));
        	if (subtasks[i][0] == null) {
        		task.setPercentComplete(states[i][0]);
        	} else {
        		for (int j = 0; j < subtasks[i].length; j++) {
        			Task subtask = new Task(subtasks[i][j], 
			                                new SimpleTimePeriod(date(subdates[i][j*2]), 
                                                                 date(subdates[i][j*2 + 1])));
        			subtask.setPercentComplete(states[i][j]);
        			task.addSubtask(subtask);
        		}
        	}
        	series.add(task);
        };

        final TaskSeriesCollection collection = new TaskSeriesCollection();
        collection.add(series);

        return collection;
    }
}
