package com.example.gantt;

import java.awt.Color;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Locale;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.AxisLocation;
import org.jfree.chart.axis.DateAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.renderer.category.CategoryItemRenderer;
import org.jfree.data.category.IntervalCategoryDataset;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;

/**
 * Пример создания диаграммы Гантта с отображением состояния задач в виде процента выполнения
 */

public class GanttChart2 extends ApplicationFrame
{
	private static final long serialVersionUID = 1L;

    public GanttChart2(final String title) {

        super(title);
        DatasetGantt ds =  new DatasetGantt();
        final JFreeChart chart = createChart(ds.createDataset2(), "Проект приложения");

        // Формат представления даты
        DateAxis axis = (DateAxis) chart.getCategoryPlot().getRangeAxis();
        DateFormat sdf = new SimpleDateFormat("MM.yyyy");
        axis.setDateFormatOverride(sdf);
        // Локализация меток
        Locale locale = new Locale("ru");
        axis.setLocale(locale);
        // Размещение оси абсцисс внизу
        chart.getCategoryPlot().setRangeAxisLocation(AxisLocation.BOTTOM_OR_LEFT);
        
        // Цвет диаграммы
        final CategoryPlot plot = (CategoryPlot) chart.getPlot();
//      plot.getDomainAxis().setMaximumCategoryLabelWidthRatio(10.0f);
        final CategoryItemRenderer renderer = plot.getRenderer();
        renderer.setSeriesPaint(0, Color.blue);

        // add the chart to a panel...
        final ChartPanel chartPanel = new ChartPanel(chart);
        chartPanel.setPreferredSize(new java.awt.Dimension(600, 450));
        setContentPane(chartPanel);

    }
    /**
     * Метод создания диаграммы
     * @param dataset набор данных
     * @return JFreeChart диаграмма Гантта 
     */
    private JFreeChart createChart(final IntervalCategoryDataset dataset, final String title) {
        final JFreeChart chart = ChartFactory.createGanttChart(
            title,   // chart title
//          "Task",  // domain axis label
            null,    // domain axis label
//          "Date",  // range axis label
            null,    // range axis label
            dataset, // data
            true,    // include legend
            true,    // tooltips
            false    // urls
        );    
        return chart;    
    }
    /**
     * Starting point for the demonstration application.
     * @param args  ignored.
     */
    public static void main(final String[] args) {

        final GanttChart2 demo = new GanttChart2("Задачи по проекту");
        demo.pack();
        RefineryUtilities.centerFrameOnScreen(demo);
        demo.setVisible(true);
    }	
}
